==> librfm5-5.3.12.tar.bz2: librfm5-5.3.12/include/rfm.h <==
/* Changes to this file shall be overwritten upon execution of configure
 * script, as rfm.h.in file is processed on package construction.
 * You have been given fair warning. */

#ifndef RFM_LIBS_H
#define RFM_LIBS_H
#include "types.h"
#include "constants.h"
#include "dbh.h"
#include "tubo.h"

// These defines are set by configuration script when librfm is installed.
#define RFM_MODULE_DIR "/usr/lib/rfm/rmodules"


# define SHOW_IT(y) if(rfm_get_widget(y)&&GTK_IS_WIDGET(rfm_get_widget(y))) gtk_widget_show_all(rfm_get_widget(y))
# define HIDE_IT(y) if(rfm_get_widget(y)&&GTK_IS_WIDGET(rfm_get_widget(y))) gtk_widget_hide(rfm_get_widget(y))


enum signal_enum_e {
    ADD_TO_VIEW_LIST,
    BOOKMARK_MONITOR
};

#ifdef HAVE_FEATURES_H
# include <features.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/wait.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <limits.h>
#include <pwd.h>
#include <grp.h>
#include <math.h>
#include <locale.h>

#ifdef HAVE_STDARG_H
# include <stdarg.h>
#elif HAVE_VARARGS_H
# include <varargs.h>
#endif

#include <ctype.h>
#include <glob.h>
#include <memory.h>
#include <signal.h>
#include <dirent.h>
#include <regex.h>


// SM is for dummies...
//#ifdef HAVE_LIBSM
//# include <X11/SMlib.h>
//#endif
//#ifdef HAVE_SM_LIBSM
//# include <X11/SM/SMlib.h>
//#endif

#include <X11/Xlib.h>
#include <X11/Xmd.h>
#include <X11/Xproto.h>
#include <X11/Xatom.h>

#include <cairo-xlib.h>
#include <gtk/gtk.h>
#include <gdk/gdkx.h>
#include <gdk/gdkkeysyms.h>
#if GTK_MAJOR_VERSION==2
# include "gdk2_3_key_compat.h"
#endif
#include <gmodule.h>
#include <time.h>
#include <sys/mman.h>

#include <pthread.h>

#include <libxml/parser.h>
#include <libxml/tree.h>
#include <magic.h>



#include "primary-types.h"
#include "primary-environment.h"
#include "primary.h"
#include "primary-compat.h"
#include "primary-layout.h"
#include "primary-completion.h"
#include "primary-modules.h"
#include "primary-preview.h"
#include "primary-icons.h"
#include "primary-misc.h"
#include "primary-run.h"
#include "primary-uri.h"
#include "primary-entry.h"
#include "primary-uri.h"
#endif

==> librfm5-5.3.16.4.tar.bz2: librfm5-5.3.16.4/include/rfm.h <==
/* Changes to this file shall be overwritten upon execution of configure
 * script, as rfm.h.in file is processed on package construction.
 * You have been given fair warning. */

#ifndef RFM_LIBS_H
#define RFM_LIBS_H
#include "types.h"
#include "constants.h"
#include "dbh.h"
#include "tubo.h"

// These defines are set by configuration script when librfm is installed.
#define RFM_MODULE_DIR "/usr/local/lib/rfm/rmodules"


# define SHOW_IT(y) if(rfm_get_widget(y)&&GTK_IS_WIDGET(rfm_get_widget(y))) gtk_widget_show_all(rfm_get_widget(y))
# define HIDE_IT(y) if(rfm_get_widget(y)&&GTK_IS_WIDGET(rfm_get_widget(y))) gtk_widget_hide(rfm_get_widget(y))


enum signal_enum_e {
    ADD_TO_VIEW_LIST,
    BOOKMARK_MONITOR
};

#ifdef HAVE_FEATURES_H
# include <features.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/wait.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <limits.h>
#include <pwd.h>
#include <grp.h>
#include <math.h>
#include <locale.h>

#ifdef HAVE_STDARG_H
# include <stdarg.h>
#elif HAVE_VARARGS_H
# include <varargs.h>
#endif

#include <ctype.h>
#include <glob.h>
#include <memory.h>
#include <signal.h>
#include <dirent.h>
#include <regex.h>


// SM is for dummies...
//#ifdef HAVE_LIBSM
//# include <X11/SMlib.h>
//#endif
//#ifdef HAVE_SM_LIBSM
//# include <X11/SM/SMlib.h>
//#endif

#include <X11/Xlib.h>
#include <X11/Xmd.h>
#include <X11/Xproto.h>
#include <X11/Xatom.h>

#include <cairo-xlib.h>
#include <gtk/gtk.h>
#include <gdk/gdkx.h>
#include <gdk/gdkkeysyms.h>
#if GTK_MAJOR_VERSION==2
# include "gdk2_3_key_compat.h"
#endif
#include <gmodule.h>
#include <time.h>
#include <sys/mman.h>

#include <pthread.h>

#include <libxml/parser.h>
#include <libxml/tree.h>
#include <magic.h>



#include "primary-types.h"
#include "primary-environment.h"
#include "primary.h"
#include "primary-compat.h"
#include "primary-layout.h"
#include "primary-completion.h"
#include "primary-modules.h"
#include "primary-preview.h"
#include "primary-icons.h"
#include "primary-misc.h"
#include "primary-run.h"
#include "primary-uri.h"
#include "primary-entry.h"
#include "primary-uri.h"
#endif
